import requests

def data():
    airportInput = str(input("Enter ICAO code: "))
    MetarbaseURL = "https://tgftp.nws.noaa.gov/data/observations/metar/stations/"
    TAFbaseurl = "https://tgftp.nws.noaa.gov/data/forecasts/taf/stations/"
    TAFurl = TAFbaseurl + airportInput.upper() + ".TXT"
    Metarurl = MetarbaseURL + airportInput.upper() + ".TXT"
    r = requests.get(Metarurl)
    p = requests.get(TAFurl)
    ask = input("Want Decoded METAR?: ")
    print("---------- METAR REPORT ----------")
    print(r.text)
    print("---------- TAF REPORT ------------")
    print(p.text)


    DecodedMetarbaseURL = "https://tgftp.nws.noaa.gov/data/observations/metar/decoded/"
    Decoded_Metarurl = DecodedMetarbaseURL + airportInput.upper() + ".TXT"
    d = requests.get(Decoded_Metarurl)
    if ask == "N":
        pass

    if ask == "Not":
        pass

    if ask == "n":
        pass

    if ask == "No":
        pass

    if ask == "no":
        pass

    else:
        print("---------- DECODED METAR REPORT ----------")
        print(d.text)





from distutils.core import setup
import setuptools

setup(
  name = 'AvWeather',         # How you named your package folder (MyLib)
  packages = ['AvWeather'],   # Chose the same as "name"
  version = '2.0',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Aviation METAR and TAF Reports',   # Give a short description about your library
  author = 'Siddharth Tewari',                   # Type in your name
  url = 'https://github.com/siddharth-tewari/AvWeather',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/siddharth-tewari/AvWeather/archive/refs/tags/02.tar.gz',    # I explain this later on
  keywords = ['Aviation', 'Aviation Weather', 'Metar', 'TAF'],   # Keywords that define your package best
  classifiers=[
  ],
)
